ICLRRuntimeInfo

Struct ICLRRuntimeInfo 

pub struct ICLRRuntimeInfo(/* private fields */);
This struct represents the COM ICLRRuntimeInfo interface;

Implementations

Source

impl ICLRRuntimeInfo

pub fn is_started(&self) -> bool

Checks if the CLR runtime has been started.

pub fn IsLoadable(&self) -> Result<BOOL>

Checks if the .NET runtime is loadable in the current process.

pub fn GetInterface<T>(&self, rclsid: *const GUID) -> Result<T>
where T: Interface,

Retrieves a COM interface by its class identifier.

pub fn GetVersionString( &self, pwzbuffer: PWSTR, pcchbuffer: *mut u32, ) -> Result<()>

Retrieves the version string of the CLR runtime.

pub fn GetRuntimeDirectory( &self, pwzbuffer: PWSTR, pcchbuffer: *mut u32, ) -> Result<()>

Retrieves the directory where the CLR runtime is installed.

pub fn IsLoaded(&self, hndProcess: HANDLE) -> Result<BOOL>

Checks if the runtime is loaded in a specified process.

pub fn LoadErrorString( &self, iResourceID: u32, pwzBuffer: PWSTR, pcchBuffer: *mut u32, iLocaleID: i32, ) -> Result<()>

Loads an error string by its resource ID.

pub fn LoadLibraryA(&self, pwzDllName: PCWSTR) -> Result<HMODULE>

Loads a DLL by name.

pub fn GetProcAddress(&self, pszProcName: &str) -> Result<*mut c_void>

Retrieves the address of a procedure in a loaded DLL.

pub fn SetDefaultStartupFlags( &self, dwstartupflags: u32, pwzhostconfigfile: PCWSTR, ) -> Result<()>

Sets the default startup flags for the runtime.

pub fn GetDefaultStartupFlags( &self, pdwstartupflags: *mut u32, pwzhostconfigfile: PWSTR, pcchhostconfigfile: *mut u32, ) -> Result<()>

Retrieves the default startup flags for the runtime.

pub fn BindAsLegacyV2Runtime(&self) -> Result<()>

Configures the runtime to behave as a legacy v2 runtime.

pub fn IsStarted( &self, pbstarted: *mut BOOL, pdwstartupflags: *mut u32, ) -> Result<()>

Checks if the runtime has started and retrieves startup flags.