pub struct ICLRRuntimeInfo(/* private fields */);Expand description
This struct represents the COM ICLRRuntimeInfo interface;
Implementations
Sourceimpl ICLRRuntimeInfo
impl ICLRRuntimeInfo
Sourcepub fn is_started(&self) -> bool
pub fn is_started(&self) -> bool
Checks if the CLR runtime has been started.
Sourcepub fn IsLoadable(&self) -> Result<BOOL>
pub fn IsLoadable(&self) -> Result<BOOL>
Checks if the .NET runtime is loadable in the current process.
Sourcepub fn GetInterface<T>(&self, rclsid: *const GUID) -> Result<T>where
T: Interface,
pub fn GetInterface<T>(&self, rclsid: *const GUID) -> Result<T>where
T: Interface,
Retrieves a COM interface by its class identifier.
Sourcepub fn GetVersionString(
&self,
pwzbuffer: PWSTR,
pcchbuffer: *mut u32,
) -> Result<()>
pub fn GetVersionString( &self, pwzbuffer: PWSTR, pcchbuffer: *mut u32, ) -> Result<()>
Retrieves the version string of the CLR runtime.
Sourcepub fn GetRuntimeDirectory(
&self,
pwzbuffer: PWSTR,
pcchbuffer: *mut u32,
) -> Result<()>
pub fn GetRuntimeDirectory( &self, pwzbuffer: PWSTR, pcchbuffer: *mut u32, ) -> Result<()>
Retrieves the directory where the CLR runtime is installed.
Sourcepub fn IsLoaded(&self, hndProcess: HANDLE) -> Result<BOOL>
pub fn IsLoaded(&self, hndProcess: HANDLE) -> Result<BOOL>
Checks if the runtime is loaded in a specified process.
Sourcepub fn LoadErrorString(
&self,
iResourceID: u32,
pwzBuffer: PWSTR,
pcchBuffer: *mut u32,
iLocaleID: i32,
) -> Result<()>
pub fn LoadErrorString( &self, iResourceID: u32, pwzBuffer: PWSTR, pcchBuffer: *mut u32, iLocaleID: i32, ) -> Result<()>
Loads an error string by its resource ID.
Sourcepub fn LoadLibraryA(&self, pwzDllName: PCWSTR) -> Result<HMODULE>
pub fn LoadLibraryA(&self, pwzDllName: PCWSTR) -> Result<HMODULE>
Loads a DLL by name.
Sourcepub fn GetProcAddress(&self, pszProcName: &str) -> Result<*mut c_void>
pub fn GetProcAddress(&self, pszProcName: &str) -> Result<*mut c_void>
Retrieves the address of a procedure in a loaded DLL.
Sourcepub fn SetDefaultStartupFlags(
&self,
dwstartupflags: u32,
pwzhostconfigfile: PCWSTR,
) -> Result<()>
pub fn SetDefaultStartupFlags( &self, dwstartupflags: u32, pwzhostconfigfile: PCWSTR, ) -> Result<()>
Sets the default startup flags for the runtime.
Sourcepub fn GetDefaultStartupFlags(
&self,
pdwstartupflags: *mut u32,
pwzhostconfigfile: PWSTR,
pcchhostconfigfile: *mut u32,
) -> Result<()>
pub fn GetDefaultStartupFlags( &self, pdwstartupflags: *mut u32, pwzhostconfigfile: PWSTR, pcchhostconfigfile: *mut u32, ) -> Result<()>
Retrieves the default startup flags for the runtime.
Sourcepub fn BindAsLegacyV2Runtime(&self) -> Result<()>
pub fn BindAsLegacyV2Runtime(&self) -> Result<()>
Configures the runtime to behave as a legacy v2 runtime.