pub struct _AppDomain(/* private fields */);Expand description
This struct represents the COM _AppDomain interface.
Implementations
Sourceimpl _AppDomain
impl _AppDomain
Sourcepub fn load_bytes(&self, buffer: &[u8]) -> Result<_Assembly>
pub fn load_bytes(&self, buffer: &[u8]) -> Result<_Assembly>
Loads an assembly into the current application domain from a byte slice.
Sourcepub fn load_name(&self, name: &str) -> Result<_Assembly>
pub fn load_name(&self, name: &str) -> Result<_Assembly>
Loads an assembly by its name in the current application domain.
Sourcepub fn from_raw(raw: *mut c_void) -> Result<_AppDomain>
pub fn from_raw(raw: *mut c_void) -> Result<_AppDomain>
Creates an _AppDomain instance from a raw COM interface pointer.
Sourcepub fn get_assembly(&self, assembly_name: &str) -> Result<_Assembly>
pub fn get_assembly(&self, assembly_name: &str) -> Result<_Assembly>
Searches for an assembly by name within the current AppDomain.
Sourcepub fn assemblies(&self) -> Result<Vec<(String, _Assembly)>>
pub fn assemblies(&self) -> Result<Vec<(String, _Assembly)>>
Retrieves all assemblies currently loaded in the AppDomain.
Sourcepub fn Load_3(&self, rawAssembly: *mut SAFEARRAY) -> Result<_Assembly>
pub fn Load_3(&self, rawAssembly: *mut SAFEARRAY) -> Result<_Assembly>
Calls the Load_3 method from the vtable of the _AppDomain interface.
Sourcepub fn Load_2(&self, assemblyString: BSTR) -> Result<_Assembly>
pub fn Load_2(&self, assemblyString: BSTR) -> Result<_Assembly>
Calls the Load_2 method from the vtable of the _AppDomain interface.
Sourcepub fn GetHashCode(&self) -> Result<u32>
pub fn GetHashCode(&self) -> Result<u32>
Calls the GetHashCode method from the vtable of the _AppDomain interface.
Sourcepub fn GetType(&self) -> Result<_Type>
pub fn GetType(&self) -> Result<_Type>
Retrieves the primary type associated with the current app domain.
Sourcepub fn GetAssemblies(&self) -> Result<*mut SAFEARRAY>
pub fn GetAssemblies(&self) -> Result<*mut SAFEARRAY>
Retrieves the assemblies currently loaded into the current AppDomain.